@@ -5,14 +5,14 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
+our $VERSION = '0.0105';
+
 use List::Util qw( min );
 use Readonly;
 
 Readonly my $SIZE  => 3;  # Triad chord
 Readonly my $SCALE => 12; # Scale notes
 
-our $VERSION = '0.0104';
-
 
 sub barycenter {
     my $size  = shift || $SIZE;  # Default to a triad
@@ -84,13 +84,13 @@ Music::Interval::Barycentric - Compute barycentric musical interval space
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
  use Music::Interval::Barycentric;
  print join(', ', Music::Interval::Barycentric::barycenter(3)), "\n";
- @chords = [qw(3 4 5), qw(0 4 7)];
+ my @chords = ([3, 4, 5], [0, 4, 7]);
  printf "D: %.3f\n", Music::Interval::Barycentric::distance($chords[0], $chords[1]);
  print Music::Interval::Barycentric::evenness_index($chords[0]);
  print Music::Interval::Barycentric::orbit_distance(@chords), "\n";
